Module: Tramway::Table::ContentCells
- Included in:
- HeaderComponent, RowComponent
- Defined in:
- app/components/tramway/table/content_cells.rb
Overview
Helpers for extracting and normalizing visible table content cells from HTML fragments.
Helpers for extracting and normalizing visible table content cells from HTML fragments.